pub trait Sink: Send {
// Required methods
fn append(self: Box<Self>, entry: &EntryInfo, name: &str) -> AppendResult;
fn seal(self: Box<Self>) -> Box<dyn Sealed>;
}Expand description
Every sink that can consume directory entry information implements this trait.
Required Methods
Sourcefn append(self: Box<Self>, entry: &EntryInfo, name: &str) -> AppendResult
fn append(self: Box<Self>, entry: &EntryInfo, name: &str) -> AppendResult
Try to append an entry with the specified entry name and attributes into this sink.
If the entry was successfully added the result is AppendResult::Ok. If the sink could
could not consume this entry an AppendResult::Sealed value is returned.
entry is the EntryInfo attributes of the next entry. name is the name of the next
entry.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".