pub struct Tokenizable<T: TokenInterface>(/* private fields */);Expand description
Tokenizable is to be used to wrap anything that might need to have tokens generated. It will ensure that the token is unregistered when Tokenizable is dropped.
Implementations