pub trait GetRemoteDir {
// Required method
fn get_remote_dir(&self) -> Result<DirectoryProxy, Status>;
}Expand description
A trait that can be implemented to return a directory proxy that should be used as a remote directory.
Required Methods
fn get_remote_dir(&self) -> Result<DirectoryProxy, Status>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".